var commandReport = function (command, mqttClient) {
    

    function formatMacAddress(mac) {
        // cihazdan gelen mac adresini 000000000000 formatından 00:00:00:00:00:00 formatına çeviriyoruz
        if (mac && mac.length === 12) {
            return mac.match(/.{1,2}/g).join(':');
        }
        return mac; 
    }

    var wiredMac = formatMacAddress(networkPlugin.GetMAC(1)); 
    var wirelessMac = formatMacAddress(networkPlugin.GetMAC(0)); 
    var wiredIP = networkPlugin.GetIP(1); 
    var wirelessIP = networkPlugin.GetIP(0); 
    var wiredDNS = networkPlugin.GetDNS(1); 
    var wirelessDNS = networkPlugin.GetDNS(0); 
    var wiredGateway = networkPlugin.GetGateway(1); 
    var wirelessGateway = networkPlugin.GetGateway(0); 
    var wiredMask = networkPlugin.GetNetMask(1); 
    var wirelessMask = networkPlugin.GetNetMask(0);

    var messagePayload = JSON.stringify({
        command_id: command.command_id,
        screen_id: command.screen_id,
        screen_uuid: command.screen_uuid,
        command: "report",
        payload: {
            octopus: {
                tag: command.screen_uuid,
                platform: "Tizen",
                version: "2.0.2",
                customer_id: ""
            },
            device: {
                brand: "Samsung",
                model: "SSSP 2",
                software: "2.0.0"
            },
            status: {
                cpu: {
                    load: null,
                    temp: null
                },
                storage: [
                    {
                        name: "SSSP2-Storage",
                        total: null,
                        used: null,
                        free: null,
                        using: true
                    }
                ],
                display: [
                    {
                        name: "SSSP2-Display",
                        width: null,
                        height: null,
                        using: true
                    },
                ],
                network: [
                    {
                        interface: "eth0",
                        mac: wiredMac || null,
                        ip: wiredIP ||null,
                        netmask: wiredMask || null,
                        gateway: wiredGateway || null,
                        dns1: wiredDNS || null,
                        dns2: "",
                        using: false
                    },
                    {
                        interface: "wifi",
                        mac: wirelessMac || "MAC alınamadı",
                        ip: wirelessIP || "IP alınamadı",
                        netmask: wirelessMask || "Netmask alınamadı",
                        gateway: wirelessGateway || "Gateway alınamadı",
                        dns1: wirelessDNS || "DNS alınamadı",
                        using: true
                    }
                ]
            }
        }
    });

    if (!command.payload || Object.keys(command.payload).length === 0) {

        var topic = "device_" + command.screen_uuid;

        var message = new Paho.MQTT.Message(messagePayload);
        message.destinationName = topic;

        mqttClient.send(message);
        log("Komut başarıyla MQTT'ye gönderildi: " + messagePayload + " | Konu: " + topic);

        wiredMac = null;
        wirelessMac = null;
        wiredIP = null;
        wirelessIP = null;
        wiredDNS = null;
        wirelessDNS = null;
        wiredGateway = null;
        wirelessGateway = null;
        wiredMask = null;
        wirelessMask = null;
        messagePayload = null;
    }
};
