var Player = {
  element: null,
  currentSceneIndex: 0,
  currentScene: null,
  screenWidth: window.availWidth,
  screenHeight: window.availHeight,
  screenRatio: 1,
  sceneTimeout: null,
  sectionTimeout: null,
  program: null,
  currentContent: {
    element: null,
    type: null,
    url: null
  },

  start: function () {
    this.element = document.getElementById("player");
    widgetAPI.putInnerHTML(this.element, "");
    this.startProgram();
  },

  startProgram: function () {
    this.currentSceneIndex = 0;
    this.program = JSON.parse(Config.get("program"));
    this.startScene(this.program.scenes, this.currentSceneIndex);
  },

  startScene: function (scenes, index) {
    if (index == scenes.length) {
      this.currentSceneIndex = 0;
      index = 0;
    }
    
    this.currentScene = scenes[index];
    this.sceneLayout(this.currentScene);

    var sceneDuration = timeToMilliseconds(this.currentScene.duration);

    var self = this;
    this.sceneTimeout = setTimeout(function () {
      if (self.sectionTimeout) {
        clearTimeout(self.sectionTimeout);
        self.sectionTimeout = null;
      }
      self.clearCurrentContent();
      self.startScene(scenes, ++self.currentSceneIndex);
    }, sceneDuration);
  },

  sceneLayout: function (scene) {
    this.clearCurrentContent();

    var fixRatio =
      scene.layout.width > window.innerWidth
        ? window.innerWidth / scene.layout.width
        : scene.layout.width / window.innerWidth;

    var self = this;

    scene.layout.sections.map(function (section) {
      var div = document.createElement("div");
      div.className = "section";

      div.style.left = section.x * fixRatio + "px";
      div.style.top = section.y * fixRatio + "px";
      div.style.width = section.w * fixRatio + "px";
      div.style.height = section.h * fixRatio + "px";

      widgetAPI.putInnerHTML(self.element, div);

      self.startSection(div, section);
    });
  },

  startSection: function (div, section) {
    section.items.sort(function (a, b) {
      return a.nth - b.nth;
    });
    this.startItem(div, section.items, 0);
  },

  startItem: function (div, items, index) {

    if (typeof items[index] != "undefined") {
      var item = items[index];


      switch (item.type) {
        case "image":
          this.showImage(LOCAL_FILE_PATH + item.file_name);
          break;
        case "video":
          this.showVideo(LOCAL_FILE_PATH + item.file_name);
          break;
        case "url":
          var meta = JSON.parse(item.meta);
          this.showURL(meta.url);
          break;
      }

      var self = this;
      switch (item.type) {
        case "image":
        case "url":
        case "video":
          if (this.sectionTimeout) {
            clearTimeout(this.sectionTimeout);
          }
          this.sectionTimeout = setTimeout(function () {
            var nextIndex = (index + 1) % items.length;
            self.startItem(div, items, nextIndex);
          }, item.duration);
          break;
      }
    } else {
    }
  },

  showVideo: function (url) {
    try {
      
      var existingVideos = this.element.getElementsByTagName('video');
      if (existingVideos.length > 0) {
        for (var i = existingVideos.length - 1; i >= 0; i--) {
          try {
            var video = existingVideos[i];
            video.pause();
            video.removeAttribute('src'); // kaynağı kaldır
            video.load(); // yeni durum için hazırla
            video.remove();
          } catch (error) {
          }
        }
      }

      this.clearCurrentContent();
      
      var video = document.createElement("video");
      if (!video) {
        throw new Error("Video elementi oluşturulamadı");
      }
      

      video.className = "play-item";
      video.preload = "auto";
      video.autoplay = true;
      video.muted = true;
      video.controls = false;
      video.loop = false;

      video.onerror = function() {
      };

      video.onloadeddata = function() {
      };

      this.element.appendChild(video);
      video.src = url;

      this.currentContent = {
        element: video,
        type: "video",
        url: url
      };


      try {
        var playPromise = video.play();
        if (playPromise !== undefined) {
          playPromise.then(function() {
          }).catch(function(error) {
          });
        }
      } catch (error) {
      }

      return video;

    } catch (error) {
      this.clearCurrentContent();
    }
  },

  showImage: function (url) {
    this.clearCurrentContent();

    var image = document.createElement("img");
    this.element.appendChild(image);

    image.className = "play-item";
    image.src = url;

    this.currentContent = {
      element: image,
      type: "image",
      url: url
    };

  },

  showURL: function (url) {
    this.clearCurrentContent();

    var iframe = document.createElement("iframe");
    iframe.className = "play-item";
    iframe.src = url;
    iframe.setAttribute("scrolling", "no");

    this.element.appendChild(iframe);

    this.currentContent = {
      element: iframe,
      type: "url",
      url: url
    };

  },

  clearCurrentContent: function() {
    if (this.currentContent.element) {
      
      if (this.currentContent.type === "video") {
        try {
          var video = this.currentContent.element;
          video.pause();
          video.removeAttribute('src'); // kaynağı kaldır
          video.load(); // yeni durum için hazırla
        } catch (error) {
        }
      }
      
      try {
        this.currentContent.element.remove();
      } catch (error) {
      }

      this.currentContent = {
        element: null,
        type: null,
        url: null
      };
      
      try {
        widgetAPI.putInnerHTML(this.element, "");
      } catch (error) {
      }
      
    }
  }
};